#!/usr/bin/env fades

"""Build a static xsario page."""


import sys
import pathlib
from collections import defaultdict

import yaml  # fades


TEMPLATE_HEADER = """
<html>
<head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
    <title>{title}</title>
</head>
<body>
<div class="heading">
    <h2>{title}</h2>
    <h3>{subtitle}</h3>
</div>

<div>
{images}
{description}
</div>

<div>
<ul>
{phrases}
</ul>
</div>

<br/>
<img src="python-powered.png" alt="Python Powered" />
</body>
</html>
"""

TEMPLATE_DESCRIP = "<p>{line}</p>\n"
TEMPLATE_IMAGE = '<img src="{filename}" />\n'
TEMPLATE_PHRASE_DATE = """
<li>{date}<ul>
{phrases}
</ul></li>
"""
TEMPLATE_PHRASE_ITEM = '<li>({time}) {phrase}</li>'


def main(basedir):
    metadata = yaml.safe_load((basedir / "metadata.yaml").read_text())

    desc_block_lines = [x.split("\n") for x in metadata["description"].split("\n\n")]
    description = "\n".join(
        TEMPLATE_DESCRIP.format(line="".join(block)) for block in desc_block_lines
    )
    images = "".join(
        TEMPLATE_IMAGE.format(filename=filename) for filename in metadata["images"]
    )

    phrases_raw = [x.strip() for x in (basedir / "frases.txt").read_text().split("\n")]
    phrases = defaultdict(list)
    for phrase_raw in phrases_raw:
        if not phrase_raw:
            continue
        date, hourmin, phrase = phrase_raw.split(maxsplit=2)
        phrases[date].append((hourmin, phrase))

    full_phrases = []
    for date, content in sorted(phrases.items(), reverse=True):
        items = []
        for hourmin, phrase in sorted(content, reverse=True):
            item = TEMPLATE_PHRASE_ITEM.format(time=hourmin, phrase=phrase)
            items.append(item)
        full_phrases.append(TEMPLATE_PHRASE_DATE.format(date=date, phrases="\n".join(items)))

    full_phrases = "\n".join(full_phrases)

    html = TEMPLATE_HEADER.format(
        title=metadata["title"],
        subtitle=metadata.get("subtitle", ""),
        description=description,
        images=images,
        phrases=full_phrases,
    )
    (basedir / "index.html").write_text(html)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("USAGE: gen_html.py basedir")
        exit()
    main(pathlib.Path(sys.argv[1]))
